---
title: <span class="badge builder"></span> HideSeriesConfig
---
# <span class="badge builder"></span> HideSeriesConfig

## Constructor

```python
HideSeriesConfig()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> common.HideSeriesConfig
```

### <span class="badge object-method"></span> legend

```python
def legend(legend: bool) -> typing.Self
```

### <span class="badge object-method"></span> tooltip

```python
def tooltip(tooltip: bool) -> typing.Self
```

### <span class="badge object-method"></span> viz

```python
def viz(viz: bool) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [HideSeriesConfig](./object-HideSeriesConfig.md)
